@@ -59,14 +59,13 @@ except ImportError:
         return _convert(node_or_string)
 
 
-__version__ = '0.10'
+__version__ = '0.11'
 __all__ = ['Client', 'Model', 'Record', 'RecordList', 'Service', 'read_config']
 
 CONF_FILE = 'erppeek.ini'
 DEFAULT_URL = 'http://localhost:8069'
 DEFAULT_DB = 'openerp'
 DEFAULT_USER = 'admin'
-DEFAULT_PASSWORD = 'admin'
 MAXCOL = [79, 179, 9999]    # Line length in verbose mode
 
 USAGE = """\
@@ -381,6 +380,7 @@ class Client(object):
         return uid
 
     # Needed for interactive use
+    connect = None
     _login = login
     _login.cache = {}
 
@@ -429,7 +429,6 @@ class Client(object):
 
     @classmethod
     def _set_interactive(cls):
-        g = globals()
         # Don't call multiple times
         del Client._set_interactive
         global_names = ['wizard', 'exec_workflow', 'read', 'search', 'count',
@@ -437,10 +436,11 @@ class Client(object):
 
         def connect(self, env=None):
             if env:
-                client = self.from_config(env, verbose=self._verbose)
+                client = self.from_config(env, verbose=self.db._verbose)
             else:
                 client = self
                 env = self._environment or self._db
+            g = globals()
             g['client'] = client
             # Tweak prompt
             sys.ps1 = '%s >>> ' % env
@@ -496,6 +496,10 @@ class Client(object):
             context = None
         elif method == 'search_count':
             params = searchargs(params)
+        elif method == 'perm_read':
+            # broken with a single id (verified with 5.0 and 6.1)
+            if params and isinstance(params[0], int_types):
+                params = ([params[0]],) + params[1:]
         if context:
             params = params + (context,)
         # Ignore extra keyword arguments
@@ -667,7 +671,7 @@ class Client(object):
         return dict([(mixedcase(name), self._model(name)) for name in names])
 
     def model(self, name):
-        """Return a :class:Model instance.
+        """Return a :class:`Model` instance.
 
         The argument `name` is the name of the model.
         """
@@ -722,15 +726,21 @@ class Client(object):
 
     def access(self, obj, mode='read'):
         """Wrapper for :meth:`Model.access` method."""
+        try:
+            self._execute('ir.model.access', 'check', obj, mode)
+            return True
+        except (TypeError, Fault):
+            return False
+
         return self.model(obj).access(mode=mode)
 
     def __getattr__(self, method):
-        if method.startswith('__'):
-            raise AttributeError("'Client' object has no attribute %r" % method)
         if not method.islower():
             rv = self.model(lowercase(method))
             self.__dict__[method] = rv
             return rv
+        if method.startswith('__'):
+            raise AttributeError("'Client' object has no attribute %r" % method)
 
         # miscellaneous object methods
         def wrapper(self, obj, *params, **kwargs):
@@ -794,24 +804,24 @@ class Model(object):
         are ``read``, ``write``, ``create`` and ``unlink``. If omitted,
         the ``read`` mode is checked.  Return a boolean.
         """
-        try:
-            self.client._execute('ir.model.access', 'check', self._name, mode)
-            return True
-        except (TypeError, Fault):
-            return False
+        return self.client.access(self._name, mode)
 
-    def browse(self, ids, context=None):
+    def browse(self, domain, *params, **kwargs):
         """Return a :class:`Record` or a :class:`RecordList`.
 
-        The argument `ids` accepts a single integer ``id``, a list of ids
+        The argument `domain` accepts a single integer ``id``, a list of ids
         or a search domain.
         If it is a single integer, the return value is a :class:`Record`.
         Otherwise, the return value is a :class:`RecordList`.
         """
+        context = kwargs.pop('context', None)
+        assert issearchdomain(domain) or not (params or kwargs)
+        ids = domain
         if isinstance(ids, int_types):
             return Record(self, ids, context=context)
-        if issearchdomain(ids):
-            ids = self._execute('search', ids, context=context)
+        if issearchdomain(domain):
+            params = searchargs((domain,) + params, kwargs, context)
+            ids = self._execute('search', *params)
         return RecordList(self, ids, context=context)
 
     # alias
@@ -919,17 +929,15 @@ class RecordList(object):
         return values
 
     def __getitem__(self, key):
-        if isinstance(key, slice):
-            return RecordList(
-                self._model, self._idnames[key], context=self._context)
-        return Record(self._model, self._idnames[key], context=self._context)
+        cls = isinstance(key, slice) and RecordList or Record
+        return cls(self._model, self._idnames[key], context=self._context)
 
     def __getattr__(self, attr):
         context = self._context
         if attr in self._model._keys:
             return self.read(attr, context=context)
         if attr.startswith('__'):
-            errmsg = "'RecordList' object has ""no attribute %r" % attr
+            errmsg = "'RecordList' object has no attribute %r" % attr
             raise AttributeError(errmsg)
         model_name = self._model._name
         execute = self._model.client.execute
@@ -952,7 +960,7 @@ class Record(object):
     The fields can be accessed through attributes.  The changes are immediately
     saved in the database.
     The ``many2one``, ``one2many`` and ``many2many`` attributes are followed
-    when the record is read.  Howeverm, when writing on these special fields,
+    when the record is read.  However when writing in these relational fields,
     use the appropriate syntax described in the official OpenERP documentation.
     The attributes are evaluated lazily, and they are cached in the record.
     The cache is invalidated if the :meth:`~Record.write` or the
@@ -1018,6 +1026,16 @@ class Record(object):
         else:
             return self._update({fields: rv})[fields]
 
+    def perm_read(self, context=None):
+        """Read the metadata of the :class:`Record`.
+
+        Return a dictionary of values.
+        See :meth:`Client.perm_read` for details.
+        """
+        rv = self.client.perm_read(self._model_name, [self.id],
+                                   context=context)
+        return rv and rv[0] or None
+
     def write(self, values, context=None):
         """Write the `values` in the :class:`Record`."""
         if context is None and self._context:
@@ -1044,8 +1062,8 @@ class Record(object):
         """
         if context is None and self._context:
             context = self._context
-        new_id = self.client.copy(self._model_name, 'copy', self.id,
-                                  default=default, context=context)
+        new_id = self.client.execute(self._model_name, 'copy', self.id,
+                                     default, context=context)
         return Record(self._model, new_id)
 
     def __dir__(self):
@@ -1145,9 +1163,12 @@ def _interact(use_pprint=True, usage=USAGE):
 
 
 def main():
+    description = ('Inspect data on OpenERP objects.  Use interactively '
+                   'or query a model (-m) and pass search terms or '
+                   'ids as positional parameters after the options.')
     parser = optparse.OptionParser(
-        usage='%prog [options] [id [id ...]]', version=__version__,
-        description='Inspect data on OpenERP objects')
+        usage='%prog [options] [search_term_or_id [search_term_or_id ...]]', version=__version__,
+        description=description)
     parser.add_option(
         '-l', '--list', action='store_true', dest='list_env',
         help='list sections of the configuration')
@@ -1163,27 +1184,22 @@ def main():
     parser.add_option('-d', '--db', default=DEFAULT_DB, help='database')
     parser.add_option('-u', '--user', default=DEFAULT_USER, help='username')
     parser.add_option(
-        '-p', '--password', default=DEFAULT_PASSWORD,
-        help='password (yes this will be in your shell history and '
-             'ps from other users)')
+        '-p', '--password', default=None,
+        help='password, or it will be requested on login')
     parser.add_option(
         '-m', '--model',
         help='the type of object to find')
-    parser.add_option(
-        '-s', '--search', action='append',
-        help='search condition (multiple allowed); alternatively, pass '
-             'multiple IDs as positional parameters after the options')
     parser.add_option(
         '-f', '--fields', action='append',
         help='restrict the output to certain fields (multiple allowed)')
     parser.add_option(
         '-i', '--interact', action='store_true',
-        help='use interactively')
+        help='use interactively; default when no model is queried')
     parser.add_option(
         '-v', '--verbose', default=0, action='count',
         help='verbose')
 
-    (args, ids) = parser.parse_args()
+    (args, domain) = parser.parse_args()
 
     Client._config_file = os.path.join(os.path.curdir, args.config)
     if args.list_env:
@@ -1197,22 +1213,14 @@ def main():
     if args.env:
         client = Client.from_config(args.env, verbose=args.verbose)
     else:
-        client = Client(args.server, args.db, args.user,
-                        args.password, args.verbose)
+        client = Client(args.server, args.db, args.user, args.password,
+                        verbose=args.verbose)
 
-    if args.model:
-        if args.search:
-            (searchquery,) = searchargs((args.search,))
-            ids = client.execute(args.model, 'search', searchquery)
-        if ids is None:
-            data = None
-        elif args.fields:
-            data = client.execute(args.model, 'read', ids, args.fields)
-        else:
-            data = client.execute(args.model, 'read', ids)
+    if args.model and domain and client.user:
+        data = client.execute(args.model, 'read', domain, args.fields)
         pprint(data)
 
-    if hasattr(client, 'connect'):
+    if client.connect is not None:
         # Set the globals()
         client.connect()
         # Enter interactive mode
